Structs
- Config
- Resolved credentials for the active profile.
- Config
Summary - Profile
Summary
Functions
- config_
path - config_
summary - read_
profile_ credentials - Return (url, token) for an existing profile, or None if not present.
- read_
profile_ names - Return all profile names from the config file (default first).
- recommended_
permissions - schema_
config_ path_ description - write_
profile - Write or update a single profile in the config file.