Module config

Module config 

Structs

Config
Resolved credentials for the active profile.
ConfigSummary
ProfileSummary

Functions

config_path
config_summary
read_profile_credentials
Return (url, token) for an existing profile, or None if not present.
read_profile_names
Return all profile names from the config file (default first).
recommended_permissions
schema_config_path_description
write_profile
Write or update a single profile in the config file.